@@ -387,6 +387,15 @@ async def update_or_create_redis_instance_from_django_instance(
         django_instance,
         cache_conf,
 ):
+    if redis_root.performance['enabled']:
+        if 'update_or_create_redis_instance_from_django_instance' not in redis_root.performance.keys():
+            redis_root.performance['update_or_create_redis_instance_from_django_instance'] = {
+                'requests': 0,
+                'time': 0
+            }
+        redis_root.performance['update_or_create_redis_instance_from_django_instance']['requests'] += 1
+        started_in = datetime.datetime.now()
+
     django_instance_model = django_instance.__class__
     old_redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
     redis_dict = await django_instance_to_redis_params(
@@ -415,6 +424,10 @@ async def update_or_create_redis_instance_from_django_instance(
         redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)[0]
         result_redis_instance_id = redis_instance['id']
 
+    if redis_root.performance['enabled']:
+        ended_in = datetime.datetime.now()
+        redis_root.performance['update_or_create_redis_instance_from_django_instance']['time'] += (ended_in - started_in).total_seconds()
+
     return result_redis_instance_id
 
 
@@ -438,6 +451,16 @@ async def django_instance_field_to_redis_value(
         django_field,
         cache_conf,
 ):
+    if redis_root.performance['enabled']:
+        if 'django_instance_field_to_redis_value' not in redis_root.performance.keys():
+            redis_root.performance['django_instance_field_to_redis_value'] = {
+                'requests': 0,
+                'time': 0
+            }
+        redis_root.performance['django_instance_field_to_redis_value']['requests'] += 1
+        started_in = datetime.datetime.now()
+
+
     save_related_models = cache_conf['save_related_models']
     django_field_value = await django_sync_to_async_get(django_instance, django_field.name)
     redis_value = django_field_value
@@ -476,6 +499,12 @@ async def django_instance_field_to_redis_value(
             redis_value = django_field_value.file.path
         except:
             redis_value = None
+
+
+    if redis_root.performance['enabled']:
+        ended_in = datetime.datetime.now()
+        redis_root.performance['django_instance_field_to_redis_value']['time'] += (ended_in - started_in).total_seconds()
+
     return redis_value
 
 
@@ -484,6 +513,15 @@ async def django_instance_to_redis_params(
         django_instance,
         cache_conf,
 ):
+    if redis_root.performance['enabled']:
+        if 'django_instance_to_redis_params' not in redis_root.performance.keys():
+            redis_root.performance['django_instance_to_redis_params'] = {
+                'requests': 0,
+                'time': 0
+            }
+        redis_root.performance['django_instance_to_redis_params']['requests'] += 1
+        started_in = datetime.datetime.now()
+
     redis_params = {}
     exclude_fields = cache_conf['exclude_fields']
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
@@ -502,6 +540,11 @@ async def django_instance_to_redis_params(
                     )
                     if redis_param:
                         redis_params[django_field_name] = redis_param
+
+    if redis_root.performance['enabled']:
+        ended_in = datetime.datetime.now()
+        redis_root.performance['django_instance_to_redis_params']['time'] += (ended_in - started_in).total_seconds()
+
     return redis_params
 
 
