@@ -539,7 +539,8 @@ class RedisRoot:
         def django_field_params_to_redis_field_params(django_field, redis_root, save_related_models, exclude_fields):
             allowed_params = ['default', 'choices', 'remote_field']
             allowed_redis_params = {}
-            for django_field_param_name in django_field.__dict__.keys():
+            django_field_params = django_field.__dict__.copy()
+            for django_field_param_name in django_field_params.keys():
                 redis_field_param_name = django_field_param_name
                 if django_field_param_name in allowed_params:
                     value = getattr(django_field, django_field_param_name)
